@@ -133,7 +133,7 @@ pref("keyword.URL", "chrome://browser-region/locale/region.properties");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
-pref("general.useragent.extra.firefox", "Minefield/3.0pre");
+pref("general.useragent.extra.firefox", "GranParadiso/3.0.1pre");
 
 pref("general.smoothScroll", false);
 //@line 180 "/builds/tinderbox/Fx-Trunk/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/app/profile/firefox.js"
